Heatmap of pairwise RV coefficients between blocks, showing which data sources tell similar stories.
Usage
plot_block_similarity(x, method = c("RV", "RV2"), ...)Heatmap of pairwise RV coefficients between blocks, showing which data sources tell similar stories.
plot_block_similarity(x, method = c("RV", "RV2"), ...)