For Linked MFA models with feature groups, shows how grouped features align in the loading space.
Usage
plot_feature_groups(x, dims = c(1, 2), groups = NULL, show_centers = TRUE, ...)For Linked MFA models with feature groups, shows how grouped features align in the loading space.
plot_feature_groups(x, dims = c(1, 2), groups = NULL, show_centers = TRUE, ...)