Visualizes how well block-specific loadings align with each other, showing the effect of the penalty parameter.
Usage
plot_loading_alignment(x, dims = c(1, 2), top_n = 10, ...)Visualizes how well block-specific loadings align with each other, showing the effect of the penalty parameter.
plot_loading_alignment(x, dims = c(1, 2), top_n = 10, ...)