Prints a concise summary of a bamfa object fitted with the EM-like algorithm,
highlighting the model structure and fit.
Usage
# S3 method for class 'bamfa'
print(x, ...)Prints a concise summary of a bamfa object fitted with the EM-like algorithm,
highlighting the model structure and fit.
# S3 method for class 'bamfa'
print(x, ...)