This function checks whether the squared norms of the ROI-space coordinates (F-scores) are equal to the squared norms of the RV-space coordinates (T-scores) for each dimension, which is a fundamental property of COVSTATIS.
This function checks whether the squared norms of the ROI-space coordinates (F-scores) are equal to the squared norms of the RV-space coordinates (T-scores) for each dimension, which is a fundamental property of COVSTATIS.